/*
    Copyright (C) 2005 - 2007 Mikael Hgdahl - dronten@gmail.com

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser BaseSetupPanel Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser BaseSetupPanel Public License for more details.

    You should have received a copy of the GNU Lesser BaseSetupPanel Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

package com.googlepages.dronten.gui;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Vector;


/**
 * A lis slection dialog object.
 */
public class ListDialog extends BaseDialog implements ActionListener {
    private JList aList = null;
    private JButton aOK = null;
    private boolean aSelect = false;


    /**
     * @param owner
     * @param titleText
     * @param labelText
     * @param okText
     * @param cancelText
     * @param choices
     * @param fixed
     * @throws HeadlessException
     */
    public ListDialog(JFrame owner, String titleText, String labelText, String okText, String cancelText, Vector choices, boolean fixed) throws HeadlessException {
        super(owner, titleText, true);

        aOK = ComponentFactory.createButton(okText, "", this, 0, 0);
        JButton cancelButton = ComponentFactory.createButton(cancelText, "", this, 0, 0);
        aList = new JList(choices);
        JScrollPane listScrollPane = new JScrollPane(aList);
        JPanel mainPanel = new JPanel();
        JLabel label = new JLabel(labelText);
        JPanel buttonPanel = new JPanel();

        if (fixed) {
            Font font = new Font("courier new", Font.TRUETYPE_FONT, 11);
            aList.setFont(font);
        }

        if (okText.length() == 0) {
            aOK.setVisible(false);
        }
        if (cancelText.length() == 0) {
            cancelButton.setVisible(false);
        }
        mainPanel.setLayout(ComponentFactory.createBorderLayout(5, 5));
        buttonPanel.setLayout(new BoxLayout(buttonPanel, BoxLayout.X_AXIS));
        mainPanel.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
        mainPanel.setPreferredSize(new Dimension(700, 300));
        mainPanel.setMaximumSize(new Dimension(2000, 2000));

        buttonPanel.add(aOK);
        buttonPanel.add(cancelButton);
        mainPanel.add(label, BorderLayout.NORTH);
        mainPanel.add(listScrollPane, BorderLayout.CENTER);
        mainPanel.add(buttonPanel, BorderLayout.SOUTH);
        setContentPane(mainPanel);
        pack();
    }


    /**
     * @param actionEvent
     */
    public void actionPerformed(ActionEvent actionEvent) {
        setVisible(false);
        aSelect = actionEvent.getSource() == aOK;
    }


    /**
     * @return Is a row selected?
     */
    public boolean isSelected() {
        return aSelect;
    }


    /**
     * @return Index of selected row
     */
    public int selectedIndex() {
        return aList.getSelectedIndex();
    }
}