/*
    Copyright (C) 2005 - 2007 Mikael Hgdahl - dronten@gmail.com

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/


package com.googlepages.dronten.jripper;

import com.googlepages.dronten.gui.Application;
import com.googlepages.dronten.jripper.gui.MainWindow;
import com.googlepages.dronten.thread.ThreadCollector;
import com.googlepages.dronten.util.Log;


/**
 * This is the application object.<br>
 * And also the where the applications starts from.
 */
public class JRipper extends Application {
    private static final long serialVersionUID = 666L;
    private ThreadCollector aThreads = new ThreadCollector();
    private static JRipper aaRipper;
    private MainWindow aMainWindow = null;


    /**
     * Create gui and try to restore size and position from last time.
     */
    public JRipper() {
        super("jRipper", Constants.PREFERENCE_NAME);

        Log.get().setLogLevel(1);
        aaRipper = this;
        aMainWindow = new MainWindow();
        aThreads.start();
        restore(aMainWindow);
        aMainWindow.aMenuPanel.enableUI();
        setIcon("com/googlepages/dronten/jripper/resource/jRipper.icon.png");

        if (isWindows()) {
            Constants.CD_DEVICE_DEFAULT = "1,0,0";
        }
    }

    /*
    * Encode a string in a specific codepage.
    *
    * @param inString
    * @return
   public static String encode (String inString) {
       return inString;
       try {
           return new String(inString.getBytes(), aaCodepage);
       }
       catch (UnsupportedEncodingException e) {
           return inString;
       }
   }
    */


    /**
     * Return application object.
     *
     * @return Application object
     */
    public static JRipper get() {
        return aaRipper;
    }


    /**
     * Get thread collector
     *
     * @return The thread collector thread
     */
    public ThreadCollector getThreadCollector() {
        return aThreads;
    }


    /**
     * Return main panel.
     *
     * @return Main pamel object
     */
    public MainWindow getWin() {
        return aMainWindow;
    }


    /**
     * Quit application.
     * Save last used path and screen position.
     */
    public void quit() {
        aThreads.IS_RUNNING = false;
        super.quit();
    }


    /**
     * Start app. It accepts no cmd parametrar.
     *
     * @param args Not used
     */
    public static void main(String[] args) {
        try {
            final JRipper ripper = new JRipper();

            javax.swing.SwingUtilities.invokeLater(new Runnable() {
                public void run() {
                    ripper.setVisible(true);
                }
            });
        }
        catch (Exception e) {
            System.out.println("Exception caught in main");
            System.out.println(e.getMessage());
            System.out.println(e.getStackTrace());
            Log.get().addTime(1, "Exception caught in main: " + e.getMessage());
            Log.get().addTime(1, "Stacktrace: " + e.getStackTrace());
            System.exit(1);
        }
    }
}
