/*
    Copyright (C) 2005 - 2007 Mikael Hgdahl - dronten@gmail.com

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

package com.googlepages.dronten.jripper.gui;

import com.googlepages.dronten.gui.BaseWindow;
import com.googlepages.dronten.gui.StatusBar;
import com.googlepages.dronten.jripper.music.Album;

import java.awt.*;


/**
 * JRipper application class.
 * Create main gui stuff here.
 */
public class MainWindow extends BaseWindow {
    private static final long serialVersionUID = 666L;
    public MenuPanel aMenuPanel = null;
    public TrackPanel aTrackPanel = null;
    private StatusBar aStatusBar = null;


    /**
     * Create main application window.
     */
    public MainWindow() {
        super();
        aMenuPanel = new MenuPanel();
        aTrackPanel = new TrackPanel();
        aStatusBar = new StatusBar();

        setLayout(new BorderLayout());

        add(aTrackPanel, BorderLayout.CENTER);
        add(aMenuPanel, BorderLayout.WEST);
        add(aStatusBar, BorderLayout.SOUTH);

        aStatusBar.setMessage("Load a CD or tracks from a directory, then convert selected tracks to mp3/ogg/m4a/flac/wav files");
    }


    /**
     * Get current album.
     *
     * @return Get album object
     */
    public Album getAlbum() {
        return aTrackPanel.getAlbum();
    }


    /**
     * Get jRippers statusbar.
     *
     * @return The application statusbar
     */
    public StatusBar getStatusBar() {
        return aStatusBar;
    }


    /**
     * Get jRippers track table panel.
     *
     * @return The track table panel
     */
    public TrackPanel getTrackPanel() {
        return aTrackPanel;
    }


    /**
     * Set new album to tracktable.
     *
     * @param album
     */
    public void setAlbum(Album album) {
        aTrackPanel.setAlbum(album);
    }
}
