/*
    Copyright (C) 2005 - 2007 Mikael Hgdahl - dronten@gmail.com

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

package com.googlepages.dronten.jripper.gui;

import com.googlepages.dronten.gui.Application;
import com.googlepages.dronten.gui.ComponentFactory;
import com.googlepages.dronten.gui.HelpDialog;
import com.googlepages.dronten.gui.setup.BaseSetupPanel;
import com.googlepages.dronten.gui.setup.SetupDialog;
import com.googlepages.dronten.jripper.Constants;
import com.googlepages.dronten.jripper.JRipper;
import com.googlepages.dronten.jripper.gui.setup.*;
import com.googlepages.dronten.jripper.music.Album;
import com.googlepages.dronten.jripper.music.Track;
import com.googlepages.dronten.jripper.task.*;
import com.googlepages.dronten.util.Log;
import com.googlepages.dronten.util.Pref;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;


/**
 * The button menu object.
 * And a combobox for selecting encoding type.
 */
public class MenuPanel extends JPanel implements ActionListener {
    private static final long serialVersionUID = 666L;
    private JButton aViewLog;
    private JButton aHelp;
    private JButton aQuit;
    private JButton aLoadCD;
    private JButton aLoadCDDB;
    private JButton aLoadDir;
    private JButton aConvertCD;
    private JButton aConvertCD2;
    private JButton aSetup;
    private JButton aSelectAll = null;
    private JButton aSelectNone = null;
    private JButton aReset;
    private JComboBox aRipper;
    private static final int COMPONENT_WIDTH = 175;


    /**
     * Create menu panel.
     */
    public MenuPanel() {
        super();

        JPanel panel = new JPanel();

        setLayout(new BorderLayout());
        panel.setLayout(new BoxLayout(panel, BoxLayout.Y_AXIS));
        panel.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));

        aRipper = ComponentFactory.createCombo(Constants.ENCODER_NAME_DEFAULTS, Pref.getPref(Constants.ENCODER_KEY, Constants.ENCODER_DEFAULT), "Select encoder type.", COMPONENT_WIDTH, COMPONENT_WIDTH);
        panel.add(aRipper);
        panel.add(Box.createRigidArea(new Dimension(0, 3)));

        aConvertCD = ComponentFactory.createButton("&Encode Tracks", "<html>Start encoding of the selected tracks.</html>", this, COMPONENT_WIDTH, 0);
        panel.add(aConvertCD);
        panel.add(Box.createRigidArea(new Dimension(0, 6)));

        aConvertCD2 = ComponentFactory.createButton("Encode Complete Album", "<html>Encode all tracks from the CD.<br>The trackname will be the name of the album.<br><b>The track will end up in the artist directory!<br>Not in the directory choice set in the preferences</b></html>", this, COMPONENT_WIDTH, 0);
        panel.add(aConvertCD2);
        panel.add(Box.createRigidArea(new Dimension(0, 6)));

        panel.add(new JSeparator());
        panel.add(Box.createRigidArea(new Dimension(0, 6)));

        aLoadCD = ComponentFactory.createButton("Load &CD", "<html>Load tracks from CD.<br>If CD-Text is available on the CD it could be read by cdda2wav if the CD is an SCSI device.</html>", this, COMPONENT_WIDTH, 0);
        panel.add(aLoadCD);
        panel.add(Box.createRigidArea(new Dimension(0, 3)));

        aLoadCDDB = ComponentFactory.createButton("Load CD (CDD&B)", "<html>Load track names from cddb server.<br>Use either the http or cddbp protocol.</html>", this, COMPONENT_WIDTH, 0);
        panel.add(aLoadCDDB);
        panel.add(Box.createRigidArea(new Dimension(0, 3)));

        aLoadDir = ComponentFactory.createButton("Load &Directory", "Load tracks from a local directory.", this, COMPONENT_WIDTH, 0);
        panel.add(aLoadDir);
        panel.add(Box.createRigidArea(new Dimension(0, 6)));

        panel.add(new JSeparator());
        panel.add(Box.createRigidArea(new Dimension(0, 6)));

        aReset = ComponentFactory.createButton("C&lear Album", "Clear album data", this, 0, 0);
        panel.add(aReset);
        panel.add(Box.createRigidArea(new Dimension(0, 3)));

        aSelectAll = ComponentFactory.createButton("Select &All", "Select all tracks in track table", this, 0, 0);
        panel.add(aSelectAll);
        panel.add(Box.createRigidArea(new Dimension(0, 3)));

        aSelectNone = ComponentFactory.createButton("Select &None", "Select no tracks in track table", this, 0, 0);
        panel.add(aSelectNone);
        panel.add(Box.createRigidArea(new Dimension(0, 6)));

        panel.add(new JSeparator());
        panel.add(Box.createRigidArea(new Dimension(0, 6)));

        aSetup = ComponentFactory.createButton("&Setup", "Change jRipper Preference", this, COMPONENT_WIDTH, 0);
        panel.add(aSetup);
        panel.add(Box.createRigidArea(new Dimension(0, 3)));

        aViewLog = ComponentFactory.createButton("Show &Log", "Show work log", this, COMPONENT_WIDTH, 0);
        panel.add(aViewLog);
        panel.add(Box.createRigidArea(new Dimension(0, 3)));

        aHelp = ComponentFactory.createButton("&Help", "Show help screen", this, COMPONENT_WIDTH, 0);
        panel.add(aHelp);
        panel.add(Box.createRigidArea(new Dimension(0, 6)));

        panel.add(new JSeparator());
        panel.add(Box.createRigidArea(new Dimension(0, 6)));

        aQuit = ComponentFactory.createButton("&Quit", "Quit jRipper", this, COMPONENT_WIDTH, 0);
        panel.add(aQuit);
        panel.add(Box.createRigidArea(new Dimension(0, 3)));

        add(panel, BorderLayout.NORTH);
    }


    /**
     * Take care of button messages.
     *
     * @param actionEvent
     */
    public void actionPerformed(ActionEvent actionEvent) {
        if (actionEvent.getSource() == aViewLog) {
            HelpDialog help = new HelpDialog(Application.get(), "jRipper Log", "&Close");
            help.centerOnApplication();
            help.setVisible(true);
            help.setText(Log.get().getLogMessage());
        }
        else if (actionEvent.getSource() == aHelp) {
            String text = "<html><body>";
            text += "<h2>jRipper 2007.01</h2>";
            text += "(c) 2004 - 2007 Mikael H&#246;gdahl<br>";
            text += "dronten@gmail.com<br>";
            text += "http://dronten.googlepages.com/jripper<br>";
            text += "This program is distributed under the terms of the GPL v2.<br><br>";
            text += "<b>Setup</b><br>";
            text += "To use jRipper some criterions must be fulfilled.<br>";
            text += "jRipper uses <b>cdda2wav, lame, oggenc, oggdec, flac, faac and faad</b> programs.<br>";
            text += "If these programs are not in the path, you have to set them in the  <b>Program Paths</b> dialog.<br>";
            text += "You can skip to set the path for the program you don't intend to use.<br>";
            text += "Then the <b>base music directory</b> must be set in the <b>General Options</b> dialog.<br>";
            text += "And the last thing is to set cd device in the <b>CD Reader Settings</b> dialog.<br>";
            text += "Some common devices are preset in the device list.<br>";
            text += "If you have an ide cd reader it can probably be found at <b>/dev/cdrom</b> in linux.<br>";
            text += "Typical values for SCSI drives are 1,0,0 or 2,0,0.<br>";
            text += "Windows is using ide drives in SCSI mode<br>";
            text += "Press the <b>Probe Devices</b> button to check for SCSI drives. Works only for root user.<br>";
            text += "There are more settings available for the cd reader but they are not necessary for using jRipper.<br><br>";
            text += "<b>Encoder</b><br>";
            text += "To change the encoder settings, read the manual pages for the encoder programs,<br>";
            text += "and change parameters in <b>Encoder Parameters</b> dialog.<br>";
            text += "The preset settings are a good choice for most users.<br><br>";
            text += "<b>CDDB</b><br>";
            text += "jRipper can read cd contents from a freedb server by the http protocol.<br>";
            text += "Or by the cddbp protocol with help from cdda2wav.<br>";
            text += "It also possible that cdda2wav can read <b>CD-Text</b> information from the cd.<br><br>";
            text += "</body></html>";
            HelpDialog help = new HelpDialog(Application.get(), "jRipper Help", "&Close");
            help.centerOnApplication();
            help.setVisible(true);
            help.setHtml(text);
        }
        else if (actionEvent.getSource() == aSetup) {
            String[] choices = Constants.SETUP_DIALOG_TABS;
            BaseSetupPanel[] panels = {new General(), new FileNames(), new Tag(), new CDDB(), new Program(), new CDReader(), new Encoder()};
            SetupDialog setup = new SetupDialog(Application.get(), "jRipper Setup", "&Close", choices, panels);

            setup.centerOnApplication();
            setup.setVisible(true);
        }
        else if (actionEvent.getSource() == aLoadCD) {
            LoadCDTask task = new LoadCDTask();
            task.doTask();
        }
        else if (actionEvent.getSource() == aLoadCDDB) {
            if (Pref.getPref(Constants.CDDB_KEY, Constants.CDDB_DEFAULT) == Constants.CDDB_DEFAULT) {
                LoadCDDBTask task = new LoadCDDBTask();
                task.doTask();
            }
            else {
                LoadCDDBPTask task = new LoadCDDBPTask();
                task.doTask();
            }
        }
        else if (actionEvent.getSource() == aLoadDir) {
            LoadDirectoryTask task = new LoadDirectoryTask();
            task.doTask();
        }
        else if (actionEvent.getSource() == aConvertCD) {
            Album album = JRipper.get().getWin().getAlbum();

            if (JRipper.get().getWin().getTrackPanel().getAlbumPanel().copyAlbum(album)) {
                RipperTask task = new RipperTask(album, aRipper.getSelectedIndex());
                task.doTask();
            }
        }
        else if (actionEvent.getSource() == aConvertCD2) {
            Album album = JRipper.get().getWin().getAlbum();

            if (JRipper.get().getWin().getTrackPanel().getAlbumPanel().copyAlbum(album)) {
                WholeCDRipperTask task = new WholeCDRipperTask(album, aRipper.getSelectedIndex());
                task.doTask();
            }
        }
        else if (actionEvent.getSource() == aReset) {
            JRipper.get().getWin().aTrackPanel.getAlbumPanel().reset();
        }
        else if (actionEvent.getSource() == aSelectAll) {
            Album album = JRipper.get().getWin().getAlbum();
            if (album == null) {
                return;
            }
            for (Track track : album.aTracks) {
                track.aSelected = true;
            }
            JRipper.get().getWin().aTrackPanel.fire();
        }
        else if (actionEvent.getSource() == aSelectNone) {
            Album album = JRipper.get().getWin().getAlbum();
            if (album == null) {
                return;
            }
            for (Track track : album.aTracks) {
                track.aSelected = false;
            }
            JRipper.get().getWin().aTrackPanel.fire();
        }
        else if (actionEvent.getSource() == aQuit) {
            JRipper.get().quit();
        }

        enableUI();
    }


    /**
     * Enable or disable ui stuff in the mneu panel depending on status.
     */
    public void enableUI() {
        Album album = JRipper.get().getWin().getAlbum();

        if (album != null && album.aTracks.size() > 0) {
            aConvertCD.setEnabled(true);
            aConvertCD2.setEnabled(album.aCD);
            aSelectAll.setEnabled(true);
            aSelectNone.setEnabled(true);
        }
        else {
            aConvertCD.setEnabled(false);
            aConvertCD2.setEnabled(false);
            aSelectAll.setEnabled(false);
            aSelectNone.setEnabled(false);
        }
    }
}
