/*
    Copyright (C) 2005 - 2007 Mikael Hgdahl - dronten@gmail.com

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

package com.googlepages.dronten.jripper.task;

import com.googlepages.dronten.gui.Application;
import com.googlepages.dronten.gui.ProgressDialog;
import com.googlepages.dronten.jripper.JRipper;
import com.googlepages.dronten.jripper.music.CDDB;
import com.googlepages.dronten.jripper.task.parser.CDDBParserThread;
import com.googlepages.dronten.jripper.task.parser.ContentsParserThread;
import com.googlepages.dronten.thread.BaseThread;
import com.googlepages.dronten.thread.process.ProcessRunner;
import com.googlepages.dronten.thread.process.ReadProc;
import com.googlepages.dronten.util.Log;
import com.googlepages.dronten.util.Progress;

import java.util.Vector;


/**
 * Load track names from cddb server.
 */
public class LoadCDDBTask {
    /**
     *
     */
    public LoadCDDBTask() {
    }


    /**
     * Encode selected tracks.
     */
    public void doTask() {
        ProgressDialog dlg = new ProgressDialog(Application.get(), "Retrieving Track Names", "&Cancel", true);
        ContentsParserThread parserThread = null;
        CDDBParserThread cddbThread = null;
        ProcessRunner loadCdProc = null;
        boolean failed = false;
        Vector<BaseThread> threads = new Vector<BaseThread>();

        try {
            Progress.get().clear();
            Log.get().clear();
            JRipper.get().getWin().setAlbum(null);

            parserThread = new ContentsParserThread(Log.get(), Progress.get());
            parserThread.aAlbum.aCD = true;
            loadCdProc = new ReadProc(Log.get(), null, Command.getCDTOCDecoder(), parserThread);
            cddbThread = new CDDBParserThread(parserThread.aAlbum, Progress.get());
            threads.add(loadCdProc);
            threads.add(cddbThread);

            dlg.centerOnApplication();
            dlg.show(threads);
        }
        catch (Exception e) {
            Log.get().addTime(1, e.getMessage());
            failed = true;
        }
        finally {
            String message = "CD data downloaded from CDDB server";
            dlg.cancelTask();

            if (loadCdProc != null && cddbThread != null) {
                if (loadCdProc.isAlive() && cddbThread.isAlive()) {
                    JRipper.get().getThreadCollector().add(loadCdProc);
                    JRipper.get().getThreadCollector().add(cddbThread);
                }
                else if (cddbThread.isAlive()) {
                    JRipper.get().getThreadCollector().add(cddbThread);
                }
                else {
                    if (loadCdProc.hasFailed()) {
                        failed = true;
                        message = "Reading CD contents failed! Check the log for more information";
                        Log.get().addTime(1, message);
                    }
                    else if (cddbThread.hasFailed()) {
                        if (CDDB.CDDB_MATCH == 0) {
                            failed = true;
                            message = "CDDB data was not found or the server was busy";
                            Log.get().addTime(1, message);
                        }
                        else if (CDDB.CDDB_MATCH == 1) {
                            failed = true;
                            message = "CD was found but contents could not be retrieved";
                            Log.get().addTime(1, message);
                        }
                    }
                    else {
                        JRipper.get().getWin().setAlbum(cddbThread.aAlbum);
                    }
                }
            }

            if (dlg.hasBeenStopped()) {
                JRipper.get().getWin().getStatusBar().setNotifyMessage("Retrieving track names has been stopped!");
            }
            else if (failed) {
                JRipper.get().getWin().getStatusBar().setErrorMessage(message);
            }
            else {
                JRipper.get().getWin().getStatusBar().setMessage(message);
            }
        }
    }
}