/*
    Copyright (C) 2005 - 2007 Mikael Hgdahl - dronten@gmail.com

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

package com.googlepages.dronten.jripper.task;

import com.googlepages.dronten.gui.Application;
import com.googlepages.dronten.gui.HelpDialog;
import com.googlepages.dronten.gui.ProgressDialog;
import com.googlepages.dronten.jripper.Constants;
import com.googlepages.dronten.jripper.JRipper;
import com.googlepages.dronten.jripper.music.Album;
import com.googlepages.dronten.jripper.music.Track;
import com.googlepages.dronten.thread.BaseThread;
import com.googlepages.dronten.util.Log;
import com.googlepages.dronten.util.Progress;
import com.googlepages.dronten.util.StopWatch;

import java.awt.*;
import java.util.Vector;


/**
 * The audio converter task.<br>
 * Ripp cd or transcode audio files.<br>
 */
public class RipperTask {
    private Album aAlbum;
    private int aEncoderIndex = 0;


    /**
     * @param album
     * @param encoderIndex
     */
    public RipperTask(Album album, int encoderIndex) {
        aEncoderIndex = encoderIndex;
        aAlbum = album;
    }


    /**
     * Encode/decode selected tracks.
     */
    public void doTask() {
        StopWatch watch = new StopWatch();
        Vector<BaseThread> threads = new Vector<BaseThread>();
        ProgressDialog dlg = new ProgressDialog(Application.get(), "Encoding Tracks", "&Cancel", true);
        boolean failed = false;
        String message = "";

        dlg.showMajorProgress();
        dlg.centerOnApplication();
        dlg.setApplication(Application.get());
        JRipper.get().getWin().getStatusBar().setMessage("Encoding selected tracks");

        Progress.get().clear();
        Log.get().clear();
        watch.start();

        try {
            for (Track track : aAlbum.aTracks) {
                if (track.aSelected) {
                    track.setEncoderIndex(aEncoderIndex);
                    String fileName = track.createFileName(aAlbum, false);

                    if (track.getDecoder() != Constants.CD_TRACK && track.aFile.equalsIgnoreCase(fileName)) {
                        throw new Exception("The encoded file will have the same filename as the decoded.\nThat will not do!\nChange encoder type, titlename or artist/album.\n" + track.aFile);
                    }
                    else {
                        switch (track.getDecoder()) {
                            case Constants.CD_TRACK:
                                Command.createEncoderForCD(aAlbum, track, threads, fileName, false);
                                break;

                            case Constants.MP3_TRACK:
                            case Constants.OGG_TRACK:
                            case Constants.M4A_TRACK:
                            case Constants.FLAC_TRACK:
                                Command.createEncoderForFiles(aAlbum, track, threads, fileName);
                                break;

                            case Constants.WAV_TRACK:
                                Command.createEncoderForWavFiles(aAlbum, track, threads, fileName);
                                break;

                            default:
                                throw new Exception("Select another encoding type for selected source.\nYou can't convert from one format to the SAME format!");
                        }
                    }
                }
            }

            if (threads.size() < 1) {
                throw new Exception("Select at least one track to encode");

            }

            dlg.show(threads); // Run all threads one by one in the progress dialog

            if (dlg.hasBeenStopped()) {
                throw new Exception("Encoding/decoding work has been stopped!");

            }
            else if (dlg.hasFailed()) {
                throw new Exception("Encoding failed! Check the log for more information");

            }
        }
        catch (Exception e) {
            Log.get().addTime(1, e.getMessage());
            message = e.getMessage();
            failed = true;
        }
        finally {
            dlg.cancelTask();
            JRipper.get().getThreadCollector().add(threads);
            watch.stop();

            if (dlg.hasBeenStopped()) {
                JRipper.get().getWin().getStatusBar().setNotifyMessage(message);
            }
            else if (failed) {
                HelpDialog showLog = new HelpDialog(Application.get(), "jRipper Log", "&Close");
                showLog.setText(Log.get().getLogMessage());
                showLog.centerOnApplication();
                showLog.setVisible(true);
                JRipper.get().getWin().getStatusBar().setErrorMessage(message);
            }
            else {
                JRipper.get().getWin().getStatusBar().setNotifyMessage("The encoding took", watch.toString());
                Toolkit.getDefaultToolkit().beep();
            }
        }
    }
}