/*
    Copyright (C) 2005 - 2007 Mikael Hgdahl - dronten@gmail.com

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

package com.googlepages.dronten.jripper.task;

import com.googlepages.dronten.gui.Application;
import com.googlepages.dronten.gui.ProgressDialog;
import com.googlepages.dronten.jripper.JRipper;
import com.googlepages.dronten.jripper.task.parser.ErrorParserThread;
import com.googlepages.dronten.jripper.task.parser.ScanbusParserThread;
import com.googlepages.dronten.thread.process.ProcessRunner;
import com.googlepages.dronten.thread.process.ReadStdoutAndStderrProc;
import com.googlepages.dronten.util.Log;
import com.googlepages.dronten.util.Progress;

import java.util.Vector;


/**
 * Scan for available SCSI drives.
 */
public class ScanbusTask {
    public Vector<String> aDevices = null;


    /**
     *
     */
    public ScanbusTask() {
    }


    /**
     * Run cdda2wav for an scanbus operation.
     */
    public void doTask() {
        ProgressDialog dlg = new ProgressDialog(Application.get(), "Probing For SCSI Devices", "&Cancel", true);
        ScanbusParserThread parserThread = null;
        ErrorParserThread errorThread = null;
        ProcessRunner runner = null;
        JRipper.get().getWin().getStatusBar().setMessage("Probing after devices");

        try {
            Progress.get().clear();
            Log.get().clear();
            JRipper.get().getWin().setAlbum(null);

            parserThread = new ScanbusParserThread(Log.get(), Progress.get());
            errorThread = new ErrorParserThread(Log.get());
            runner = new ReadStdoutAndStderrProc(Log.get(), null, Command.getScanbus(), parserThread, errorThread);

            dlg.centerOnApplication();
            dlg.show(runner);
        }
        catch (Exception e) {
            Log.get().addTime(1, e.getMessage());
        }
        finally {
            dlg.cancelTask();

            if (runner != null) {
                if (runner.isAlive()) {
                    JRipper.get().getThreadCollector().add(runner);
                }
                else if (runner.hasFailed()) {
                    JRipper.get().getWin().getStatusBar().setMessage("Something failed when probing for SCSI devices!");
                }
                else {
                    aDevices = parserThread.aDevices;
                }
            }
        }
    }
}