/*
    Copyright (C) 2005 - 2007 Mikael Hgdahl - dronten@gmail.com

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser BaseSetupPanel Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser BaseSetupPanel Public License for more details.

    You should have received a copy of the GNU Lesser BaseSetupPanel Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

package com.googlepages.dronten.jripper.task.parser;

import com.googlepages.dronten.gui.Application;
import com.googlepages.dronten.gui.ListDialog;
import com.googlepages.dronten.jripper.Constants;
import com.googlepages.dronten.jripper.music.Album;
import com.googlepages.dronten.jripper.music.CDDB;
import com.googlepages.dronten.jripper.music.DiscID;
import com.googlepages.dronten.thread.BaseThread;
import com.googlepages.dronten.util.Log;
import com.googlepages.dronten.util.Pref;
import com.googlepages.dronten.util.Progress;

import java.util.Collections;
import java.util.Vector;


/**
 * Get info about a record from cddb by the http protocol.
 */
public class CDDBParserThread extends BaseThread {
    public Album aAlbum = null;


    /**
     * @param album
     * @param progress
     */
    public CDDBParserThread(Album album, Progress progress) {
        super(Log.get(), progress);
        aAlbum = album;
        aProgress.appendTask(2000, "Contacting cddb server...", "");
    }


    /**
     * call hasFailed for detecting if retrival has been successfull.
     */
    public void run() {
        try {
            String server = Pref.getPref(Constants.CDDB_SERVER_KEY, Constants.CDDB_SERVER_DEFAULT);
            String port = Pref.getPref(Constants.CDDB_PORT_KEY, Constants.CDDB_PORT_DEFAULT);

            Vector<DiscID> discs = CDDB.queryServerForAlbum(getLog(), server, Integer.valueOf(port), aAlbum);
            if (discs.size() > 0) {
                int index = 0;
                if (discs.size() > 1) {
                    Collections.sort(discs);

                    if (aRunning) {
                        // Check again if it is running before showing dialog. It could have benn stopped long ago.
                        ListDialog dlg = new ListDialog(Application.get(), "Select Album", "There were more than one match. Select one of the albums.", "&Ok", "", discs, true);
                        dlg.centerOnApplication();
                        dlg.setVisible(true);
                        if (dlg.selectedIndex() >= 0 && dlg.selectedIndex() < discs.size()) {
                            index = dlg.selectedIndex();
                        }
                    }

                }

                if (!CDDB.getAlbumData(getLog(), server, Integer.valueOf(port), aAlbum, discs.get(index))) {
                    setFailed(true);
                }
            }
            else {
                addLog(1, "The CDDB lookup failed. Either the cd record was not found or server was busy.");
                setFailed(true);
            }
        }
        catch (NumberFormatException e2) {
            addLog(1, e2.getMessage());
            addLog(1, "Have you set the port number to something strange?");
            setFailed(true);
        }
        catch (Exception e) {
            addLog(1, e.getMessage());
            setFailed(true);
        }
    }
}
