/*
    Copyright (C) 2004 - 2005 Mikael Hogdahl

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser BaseSetupPanel Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser BaseSetupPanel Public License for more details.

    You should have received a copy of the GNU Lesser BaseSetupPanel Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

package com.googlepages.dronten.jripper.test;

import com.googlepages.dronten.jripper.Constants;
import com.googlepages.dronten.jripper.music.Album;
import com.googlepages.dronten.util.Log;
import com.googlepages.dronten.util.Pref;
import junit.framework.Assert;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.io.File;


/**
 *
 */
public class TestFilenameAndDirectory extends TestCase {
    public static String DIR = "";


    /**
     *
     */
    protected void setUp() {
        Log.get("TestRippingAndTranscoding.log");
        new Pref(Constants.PREFERENCE_NAME_DEBUG);

        if (System.getProperty("os.name").startsWith("Linux")) {
            if (DIR.length() == 0) {
                DIR = "/music";
            }
        }
        else {
            if (DIR.length() == 0) {
                DIR = "c:/Music";
            }
        }

        Pref.setPref(Constants.BASE_DIRECTORY_KEY, DIR);
    }


    /**
     *
     */
    protected void tearDown() {
    }


    /**
     * @return Test
     */
    public static Test suite() {
        return new TestSuite(TestFilenameAndDirectory.class);
    }


    /**
     *
     */
    public void test01TitleTag() {
        try {
            Album album = new Album("Artist Name", "Album Name", "Rock", "2000", "");
            String[] tagOptions = Constants.TITLE_OPTIONS;

            album.addTrack("Trackname", "01.01", "");

            Pref.setPref(Constants.TITLE_KEY, 0);
            assertEquals("Trackname", album.aTracks.get(0).createTitleTag(album, false));
            assertEquals("Title", tagOptions[0]);

            Pref.setPref(Constants.TITLE_KEY, 1);
            assertEquals("Artist Name - Trackname", album.aTracks.get(0).createTitleTag(album, false));
            assertEquals("Artist - Title", tagOptions[1]);

            Pref.setPref(Constants.TITLE_KEY, 2);
            assertEquals("Artist Name / Trackname", album.aTracks.get(0).createTitleTag(album, false));
            assertEquals("Artist / Title", tagOptions[2]);

            Pref.setPref(Constants.TITLE_KEY, 3);
            assertEquals("Artist Name - Album Name - Trackname", album.aTracks.get(0).createTitleTag(album, false));
            assertEquals("Artist - Album - Title", tagOptions[3]);

            Pref.setPref(Constants.TITLE_KEY, 4);
            assertEquals("Artist Name / Album Name / Trackname", album.aTracks.get(0).createTitleTag(album, false));
            assertEquals("Artist / Album / Title", tagOptions[4]);

            Pref.setPref(Constants.TITLE_KEY, 5);
            assertEquals("Album Name - Trackname", album.aTracks.get(0).createTitleTag(album, false));
            assertEquals("Album - Title", tagOptions[5]);

            Pref.setPref(Constants.TITLE_KEY, 6);
            assertEquals("Album Name / Trackname", album.aTracks.get(0).createTitleTag(album, false));
            assertEquals("Album / Title", tagOptions[6]);
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test01TitleTag2() {
        try {
            Album album = new Album("", "", "Rock", "2000", "");
            album.addTrack("Trackname", "01.01", "");

            Pref.setPref(Constants.TITLE_KEY, 0);
            assertEquals("Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 1);
            assertEquals("Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 2);
            assertEquals("Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 3);
            assertEquals("Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 4);
            assertEquals("Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 5);
            assertEquals("Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 6);
            assertEquals("Trackname", album.aTracks.get(0).createTitleTag(album, false));

            album = new Album("ART", "", "Rock", "2000", "");
            album.addTrack("Trackname", "01.01", "");

            Pref.setPref(Constants.TITLE_KEY, 0);
            assertEquals("Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 1);
            assertEquals("ART - Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 2);
            assertEquals("ART / Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 3);
            assertEquals("ART - Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 4);
            assertEquals("ART / Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 5);
            assertEquals("Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 6);
            assertEquals("Trackname", album.aTracks.get(0).createTitleTag(album, false));

            album = new Album("", "ALB", "Rock", "2000", "");
            album.addTrack("Trackname", "01.01", "");

            Pref.setPref(Constants.TITLE_KEY, 0);
            assertEquals("Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 1);
            assertEquals("Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 2);
            assertEquals("Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 3);
            assertEquals("ALB - Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 4);
            assertEquals("ALB / Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 5);
            assertEquals("ALB - Trackname", album.aTracks.get(0).createTitleTag(album, false));

            Pref.setPref(Constants.TITLE_KEY, 6);
            assertEquals("ALB / Trackname", album.aTracks.get(0).createTitleTag(album, false));
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test02TrackFileName() {
        try {
            Album album = new Album("Artist Name", "Album Name", "Rock", "2000", "");
            String[] dirOptions = Constants.DIRECTORY_OPTIONS;
            String[] fileOptions = Constants.FILENAME_OPTIONS;
            String[] numberOptions = Constants.FILENUMBER_OPTIONS;

            album.addTrack("Trackname", "01.01", "");

            Pref.setPref(Constants.FILENAME_KEY, 0);
            Pref.setPref(Constants.DIRECTORY_KEY, 0);
            Pref.setPref(Constants.FILENUMBER_KEY, Constants.FILENUMBER_DEFAULT);
            Pref.setPref(Constants.FILENUMBER_USE_KEY, Constants.FILENUMBER_USE_DEFAULT);
            Pref.setPref(Constants.FILENUMBER_SEPERATOR_KEY, Constants.FILENUMBER_SEPERATOR_DEFAULT);

            ////////////////// DIRECTORY_KEY //////////////////////

            Pref.setPref(Constants.DIRECTORY_KEY, 0);
            album.aTracks.get(0).setEncoderIndex(Constants.ENCODER_INDEX_MP3);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name" + File.separator + "Album Name" + File.separator + "01 Trackname.mp3", album.aTracks.get(0).createFileName(album, false));
            album.aTracks.get(0).setEncoderIndex(Constants.ENCODER_INDEX_OGG);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name" + File.separator + "Album Name" + File.separator + "01 Trackname.ogg", album.aTracks.get(0).createFileName(album, false));
            album.aTracks.get(0).setEncoderIndex(Constants.ENCODER_INDEX_WAV);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name" + File.separator + "Album Name" + File.separator + "01 Trackname.wav", album.aTracks.get(0).createFileName(album, false));
            assertEquals("Artist/Album", dirOptions[0]);

            Pref.setPref(Constants.DIRECTORY_KEY, 1);
            album.aTracks.get(0).setEncoderIndex(Constants.ENCODER_INDEX_MP3);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Rock" + File.separator + "Artist Name" + File.separator + "Album Name" + File.separator + "01 Trackname.mp3", album.aTracks.get(0).createFileName(album, false));
            assertEquals("Genre/Artist/Album", dirOptions[1]);

            Pref.setPref(Constants.DIRECTORY_KEY, 2);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name - Album Name" + File.separator + "01 Trackname.mp3", album.aTracks.get(0).createFileName(album, false));
            assertEquals("Artist - Album", dirOptions[2]);

            Pref.setPref(Constants.DIRECTORY_KEY, 3);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Rock" + File.separator + "Artist Name - Album Name" + File.separator + "01 Trackname.mp3", album.aTracks.get(0).createFileName(album, false));
            assertEquals("Genre/Artist - Album", dirOptions[3]);

            Pref.setPref(Constants.DIRECTORY_KEY, 4);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name" + File.separator + "Album Name (2000)" + File.separator + "01 Trackname.mp3", album.aTracks.get(0).createFileName(album, false));
            assertEquals("Artist/Album (Year)", dirOptions[4]);

            Pref.setPref(Constants.DIRECTORY_KEY, 5);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name - Album Name (2000)" + File.separator + "01 Trackname.mp3", album.aTracks.get(0).createFileName(album, false));
            assertEquals("Artist - Album (Year)", dirOptions[5]);

            ///////////////// FILENUMBEROPTION /////////////////

            Pref.setPref(Constants.DIRECTORY_KEY, 0);

            Pref.setPref(Constants.FILENUMBER_KEY, 0);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name" + File.separator + "Album Name" + File.separator + "1 Trackname.mp3", album.aTracks.get(0).createFileName(album, false));
            assertEquals("1", numberOptions[0]);

            Pref.setPref(Constants.FILENUMBER_KEY, 1);
            album.aTracks.get(0).setEncoderIndex(Constants.ENCODER_INDEX_MP3);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name" + File.separator + "Album Name" + File.separator + "01 Trackname.mp3", album.aTracks.get(0).createFileName(album, false));
            assertEquals("01", numberOptions[1]);

            Pref.setPref(Constants.FILENUMBER_KEY, 2);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name" + File.separator + "Album Name" + File.separator + "001 Trackname.mp3", album.aTracks.get(0).createFileName(album, false));
            assertEquals("001", numberOptions[2]);

            Pref.setPref(Constants.FILENUMBER_USE_KEY, false);
            Pref.setPref(Constants.FILENUMBER_KEY, 0);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name" + File.separator + "Album Name" + File.separator + "Trackname.mp3", album.aTracks.get(0).createFileName(album, false));

            /////////////////////// FILENUMBER_SEPERATOR_KEY /////////////////////////

            Pref.setPref(Constants.FILENUMBER_KEY, 1);
            Pref.setPref(Constants.FILENUMBER_SEPERATOR_KEY, " <> ");
            Pref.setPref(Constants.FILENUMBER_USE_KEY, true);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name" + File.separator + "Album Name" + File.separator + "01 <> Trackname.mp3", album.aTracks.get(0).createFileName(album, false));

            /////////////////////// FILENAME /////////////////////////

            Pref.setPref(Constants.FILENUMBER_KEY, 1);
            Pref.setPref(Constants.FILENUMBER_SEPERATOR_KEY, "-");

            Pref.setPref(Constants.FILENAME_KEY, 0);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name" + File.separator + "Album Name" + File.separator + "01-Trackname.mp3", album.aTracks.get(0).createFileName(album, false));
            assertEquals("Track", fileOptions[0]);

            Pref.setPref(Constants.FILENAME_KEY, 1);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name" + File.separator + "Album Name" + File.separator + "01-Artist Name - Trackname.mp3", album.aTracks.get(0).createFileName(album, false));
            assertEquals("Artist - Track", fileOptions[1]);

            Pref.setPref(Constants.FILENAME_KEY, 2);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name" + File.separator + "Album Name" + File.separator + "01-Album Name - Trackname.mp3", album.aTracks.get(0).createFileName(album, false));
            assertEquals("Album - Track", fileOptions[2]);

            Pref.setPref(Constants.FILENAME_KEY, 3);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Artist Name" + File.separator + "Album Name" + File.separator + "01-Artist Name - Album Name - Trackname.mp3", album.aTracks.get(0).createFileName(album, false));
            assertEquals("Artist - Album - Track", fileOptions[3]);
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test03TrackFileName() {
        try {
            Album album = new Album("Ar;tis:t/ Na   me  ", "A/l;b:um Name  ", "Rock", "2000", "");

            album.addTrack("Tr;ackna  me*........,,,", "01.01", "");

            Pref.setPref(Constants.FILENAME_KEY, 0);
            Pref.setPref(Constants.DIRECTORY_KEY, 0);
            Pref.setPref(Constants.FILENUMBER_KEY, Constants.FILENUMBER_DEFAULT);
            Pref.setPref(Constants.FILENUMBER_USE_KEY, Constants.FILENUMBER_USE_DEFAULT);
            Pref.setPref(Constants.FILENUMBER_SEPERATOR_KEY, Constants.FILENUMBER_SEPERATOR_DEFAULT);
            album.aTracks.get(0).setEncoderIndex(Constants.ENCODER_INDEX_MP3);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Ar;tis t Na me" + File.separator + "A l;b um Name" + File.separator + "01 Tr;ackna me.mp3", album.aTracks.get(0).createFileName(album, false));
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test04TrackFileName() {
        try {
            Album album = new Album("A/\\rt\"ist.", "Alb.u\"m.", "Rock", "2000", "");

            album.addTrack("Track \"0\"1", "01.01", "");

            Pref.setPref(Constants.FILENAME_KEY, 0);
            Pref.setPref(Constants.DIRECTORY_KEY, 0);
            Pref.setPref(Constants.FILENUMBER_KEY, Constants.FILENUMBER_DEFAULT);
            Pref.setPref(Constants.FILENUMBER_USE_KEY, Constants.FILENUMBER_USE_DEFAULT);
            Pref.setPref(Constants.FILENUMBER_SEPERATOR_KEY, Constants.FILENUMBER_SEPERATOR_DEFAULT);
            album.aTracks.get(0).setEncoderIndex(Constants.ENCODER_INDEX_MP3);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "A rtist" + File.separator + "Album" + File.separator + "01 Track 01.mp3", album.aTracks.get(0).createFileName(album, false));
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test05TrackFileName() {
        try {
            Album album = new Album("", "", "Rock", "2000", "");
            album.addTrack("Track", "01.01", "");

            Pref.setPref(Constants.DIRECTORY_KEY, 0);
            Pref.setPref(Constants.FILENUMBER_KEY, Constants.FILENUMBER_DEFAULT);
            Pref.setPref(Constants.FILENUMBER_USE_KEY, Constants.FILENUMBER_USE_DEFAULT);
            Pref.setPref(Constants.FILENUMBER_SEPERATOR_KEY, Constants.FILENUMBER_SEPERATOR_DEFAULT);
            album.aTracks.get(0).setEncoderIndex(Constants.ENCODER_INDEX_MP3);
            Pref.setPref(Constants.FILENAME_KEY, 0);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 1);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Rock" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 2);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 3);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Rock" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 4);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "(2000)" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 5);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "(2000)" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));

            album.aArtist = "foo";
            Pref.setPref(Constants.DIRECTORY_KEY, 0);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "foo" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 1);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Rock" + File.separator + "foo" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 2);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "foo" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 3);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Rock" + File.separator + "foo" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 4);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "foo" + File.separator + "(2000)" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 5);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "foo (2000)" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));

            album.aArtist = "";
            album.aAlbum = "bar";
            Pref.setPref(Constants.DIRECTORY_KEY, 0);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "bar" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 1);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Rock" + File.separator + "bar" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 2);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "bar" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 3);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Rock" + File.separator + "bar" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 4);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "bar" + " (2000)" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));
            Pref.setPref(Constants.DIRECTORY_KEY, 5);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "bar (2000)" + File.separator + "01 Track.mp3", album.aTracks.get(0).createFileName(album, false));

        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test06TrackFileName() {
        try {
            Album album = new Album("Pink Floyd", "The Wall", "Rock", "1979", "");
            album.addTrack("Another Brick In The Wall", "03.33", "");

            Pref.setPref(Constants.FILENUMBER_KEY, Constants.FILENUMBER_DEFAULT);
            Pref.setPref(Constants.FILENUMBER_USE_KEY, Constants.FILENUMBER_USE_DEFAULT);
            Pref.setPref(Constants.FILENUMBER_SEPERATOR_KEY, Constants.FILENUMBER_SEPERATOR_DEFAULT);
            Pref.setPref(Constants.FILENAME_KEY, 0);
            album.aTracks.get(0).setEncoderIndex(Constants.ENCODER_INDEX_MP3);

            Pref.setPref(Constants.DIRECTORY_KEY, 0);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Pink Floyd" + File.separator + "The Wall" + File.separator + "01 Another Brick In The Wall.mp3", album.aTracks.get(0).createFileName(album, false));

            Pref.setPref(Constants.DIRECTORY_KEY, 1);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Rock" + File.separator + "Pink Floyd" + File.separator + "The Wall" + File.separator + "01 Another Brick In The Wall.mp3", album.aTracks.get(0).createFileName(album, false));

            Pref.setPref(Constants.DIRECTORY_KEY, 2);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Pink Floyd - The Wall" + File.separator + "01 Another Brick In The Wall.mp3", album.aTracks.get(0).createFileName(album, false));

            Pref.setPref(Constants.DIRECTORY_KEY, 3);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Rock" + File.separator + "Pink Floyd - The Wall" + File.separator + "01 Another Brick In The Wall.mp3", album.aTracks.get(0).createFileName(album, false));

            Pref.setPref(Constants.DIRECTORY_KEY, 4);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Pink Floyd" + File.separator + "The Wall (1979)" + File.separator + "01 Another Brick In The Wall.mp3", album.aTracks.get(0).createFileName(album, false));

            Pref.setPref(Constants.DIRECTORY_KEY, 5);
            assertEquals(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "Pink Floyd - The Wall (1979)" + File.separator + "01 Another Brick In The Wall.mp3", album.aTracks.get(0).createFileName(album, false));
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     * @param args
     */
    public static void main(String[] args) {
        if (args.length == 1) {
            TestFilenameAndDirectory.DIR = args[0];
            junit.textui.TestRunner.run(suite());
        }
        else {
            System.out.println("Argument is base directory");
        }
        junit.textui.TestRunner.run(suite());
    }
}
