package com.googlepages.dronten.jripper.test;

import com.googlepages.dronten.jripper.task.parser.progress.*;
import com.googlepages.dronten.util.Log;
import junit.framework.Assert;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.util.Vector;
import java.util.regex.Matcher;


/**
 * Automated testcase for ripping and transcoding audio tracks.
 * All tests should work, even if some ok results are failures.
 * See test07Failure.
 */
public class TestProgressParsing extends TestCase {


    /**
     *
     */
    protected void setUp() {
        Log.get("TestProgressParsing.log");
        Log.get().setLogLevel(4);
    }


    /**
     *
     */
    protected void tearDown() {
    }


    /**
     * @return Test
     */
    public static Test suite() {
        return new TestSuite(TestProgressParsing.class);
    }


    /**
     *
     */
    public void test01CD() {
        try {
            Vector<String> strings = new Vector<String>();
            ParseCD cd = new ParseCD(false);

            strings.add("Type: ROM, Vendor 'MATSHITA' Model 'UJDA760 DVD/CDRW' Revision '1.00' MMC+CDDA");
            strings.add("983040 bytes buffer memory requested, transfer size 64512 bytes, 4 buffers, 27 sectors");
            strings.add("#Cdda2wav version 2.01.01a23_cygwin32_nt_1.5.22(0.156-4-2)_i686_i686, soundcard, libparanoia support");
            strings.add("Tracks:8 39:38.07");
            strings.add("CDINDEX discid: 7sQgT5OeyAkXCXXP0JibENfv4Cs-");
            strings.add("CDDB discid: 0x5b094a08");
            strings.add("CD-Text: detected");
            strings.add("CD-Extra: not detected");
            strings.add("Album title: 'On The Beach' from 'Neil Young'");
            strings.add("T01:       0  2:42.50 audio linear copydenied stereo title 'Walk On' from 'Neil Young'");
            strings.add("T02:   12200  5:02.35 audio linear copydenied stereo title 'See The Sky About To Rain' from 'Neil Young'");
            strings.add("T03:   34885  4:03.49 audio linear copydenied stereo title 'Revolution Blues' from 'Neil Young'");
            strings.add("T04:   53159  3:15.26 audio linear copydenied stereo title 'For The Turnstiles' from 'Neil Young'");
            strings.add("T05:   67810  4:14.52 audio linear copydenied stereo title 'Vampire Blues' from 'Neil Young'");
            strings.add("T06:   86912  6:59.23 audio linear copydenied stereo title 'On The Beach' from 'Neil Young'");
            strings.add("T07:  118360  4:23.52 audio linear copydenied stereo title 'Motion Pictures' from 'Neil Young'");
            strings.add("T08:  138137  8:56.20 audio linear copydenied stereo title 'Ambulance Blues' from 'Neil Young'");
            strings.add("Leadout:  178357");
            strings.add("samplefile size will be 28694444 bytes.");
            strings.add("recording 162.6666 seconds stereo with 16 bits @ 44100.0 Hz ->'audio'...");
            strings.add("child pid is 456");
            strings.add("percent_done:");
            strings.add("  9%");
            strings.add("100%  track  1 'Walk On' recorded successfully");
            strings.add("");

            for (String s : strings) {
                Matcher matcher = cd.getPattern().matcher(s);

                if (matcher.find()) {
                    Assert.assertEquals(1, matcher.groupCount());
                    Assert.assertEquals(9, Double.valueOf(matcher.group(1)).shortValue());
                }
            }
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test02Flac() {
        try {
            Vector<String> strings = new Vector<String>();
            ParseFlac flac = new ParseFlac(false);

            strings.add("flac 1.1.3, Copyright (C) 2000,2001,2002,2003,2004,2005,2006  Josh Coalson");
            strings.add("flac comes with ABSOLUTELY NO WARRANTY.  This is free software, and you are");
            strings.add("welcome to redistribute it under certain conditions.  Type `flac' for details.");
            strings.add("01 Maria, mnga mil och r frn hr.flac: 93% complete");
            strings.add("01 Maria, mnga mil och r frn hr.flac: done");
            strings.add("");


            for (String s : strings) {
                Matcher matcher = flac.getPattern().matcher(s);

                if (matcher.find()) {
                    Assert.assertEquals(1, matcher.groupCount());
                    Assert.assertEquals(93, Double.valueOf(matcher.group(1)).shortValue());
                }
            }
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test03M4A() {
        try {
            Vector<String> strings = new Vector<String>();
            ParseM4A m4a = new ParseM4A(false);

            strings.add(" *********** Ahead Software MPEG-4 AAC Decoder V2.5 ******************");
            strings.add("Build: Jan  2 2007");
            strings.add("Copyright 2002-2004: Ahead Software AG");
            strings.add(" http://www.audiocoding.com");
            strings.add(" Floating point version");
            strings.add(" This program is free software; you can redistribute it and/or modify");
            strings.add(" it under the terms of the GNU General Public License.");
            strings.add(" *************************************************************************");
            strings.add("C:\\Music\\Music - M4A (8888)\\04 Ett enskilt rum p Sabbatsberg.m4a file info:");
            strings.add("LC AAC\t20.367 secs, 2 ch, 44100 H");
            strings.add("tool: FAAC 1.25");
            strings.add("artist: Music");
            strings.add("title: Ett enskilt rum p Sabbatsberg");
            strings.add("album: M4A");
            strings.add("track: 4");
            strings.add("date: 8888");
            strings.add("genre: Other");
            strings.add("  ---------------------");
            strings.add(" | Config:  2 Ch       |");
            strings.add(" | Ch |    Position    |");
            strings.add("  ---------------------");
            strings.add(" | 00 | Left front     |");
            strings.add(" | 01 | Right front    |");
            strings.add("  ---------------------");
            strings.add("57% decoding C:\\Music\\Music - M4A (8888)\\04 Ett enskilt rum p Sabbatsberg.m4a.");
            strings.add("Decoding C:\\Music\\Music - M4A (8888)\\04 Ett enskilt rum p Sabbatsberg.m4a took:  3.05 sec.  6.68x real-time.");
            strings.add("");

            for (String s : strings) {
                Matcher matcher = m4a.getPattern().matcher(s);

                if (matcher.find()) {
                    Assert.assertEquals(1, matcher.groupCount());
                    Assert.assertEquals(57, Double.valueOf(matcher.group(1)).shortValue());
                }
            }
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test04Ogg() {
        try {
            Vector<String> strings = new Vector<String>();
            ParseOgg ogg = new ParseOgg(false);

            strings.add("OggDec 1.0.1");
            strings.add("Decoding \"audio.ogg\" to \"w.wav\"");
            strings.add("        [ 33.0%]");
            strings.add("");

            for (String s : strings) {
                Matcher matcher = ogg.getPattern().matcher(s);

                if (matcher.find()) {
                    Assert.assertEquals(1, matcher.groupCount());
                    Assert.assertEquals(33, Double.valueOf(matcher.group(1)).shortValue());
                }
            }
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test05MP3() {
        try {
            Vector<String> strings = new Vector<String>();
            ParseMP3 mp3 = new ParseMP3(false);

            strings.add("input:  w.wav.mp3  (44.1 kHz, 2 channels, MPEG-1 Layer III)");
            strings.add("output: f.wav  (16 bit, Microsoft WAVE)");
            strings.add("skipping initial 1105 samples (encoder+decoder delay)");
            strings.add("Frame#  3333/6666   128 kbps   MS");
            strings.add("");

            for (String s : strings) {
                Matcher matcher = mp3.getPattern().matcher(s);

                if (matcher.find()) {
                    Assert.assertEquals(2, matcher.groupCount());
                    Assert.assertEquals(3333, Double.valueOf(matcher.group(1)).shortValue());
                    Assert.assertEquals(6666, Double.valueOf(matcher.group(2)).shortValue());
                }
            }
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     * @param args
     */
    public static void main(String[] args) {
    }
}
