/*
    Copyright (C) 2004 - 2005 Mikael Hogdahl

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser BaseSetupPanel Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser BaseSetupPanel Public License for more details.

    You should have received a copy of the GNU Lesser BaseSetupPanel Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

package com.googlepages.dronten.jripper.test;

import com.googlepages.dronten.jripper.Constants;
import com.googlepages.dronten.jripper.music.Album;
import com.googlepages.dronten.jripper.music.Track;
import com.googlepages.dronten.jripper.task.Command;
import com.googlepages.dronten.thread.BaseThread;
import com.googlepages.dronten.util.Log;
import com.googlepages.dronten.util.Pref;
import static com.googlepages.dronten.util.Pref.setPref;
import com.googlepages.dronten.util.Progress;
import junit.framework.Assert;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.io.File;
import java.util.Vector;


/**
 * Automated testcase for ripping and transcoding audio tracks.
 * All tests should work, even if some ok results are failures.
 * See test07Failure.
 */
public class TestRippingAndTranscoding extends TestCase {
    public static String DEVICE = "";
    public static String DIR = "";
    public static String TRACKSTR = "01";
    public static int TRACKNUM = 1;


    /**
     *
     */
    protected void setUp() {
        Log.get("TestRippingAndTranscoding.log");
        Log.get().setLogLevel(2);
        new Pref(Constants.PREFERENCE_NAME_DEBUG);

        if (System.getProperty("os.name").startsWith("Linux")) {
            setPref(Constants.CD_READER_KEY, "./cdda2wav");
            setPref(Constants.MP3_ENCODER_KEY, "./lame");
            setPref(Constants.OGG_ENCODER_KEY, "./oggenc");
            setPref(Constants.OGG_DECODER_KEY, "./oggdec");
            setPref(Constants.AAC_ENCODER_KEY, "./faac");
            setPref(Constants.AAC_DECODER_KEY, "./faad");
            setPref(Constants.FLAC_ENCODER_KEY, "./flac");

            if (DEVICE.length() == 0) {
                DEVICE = "/dev/cdrom";
            }

            if (DIR.length() == 0) {
                DIR = "/music";
            }
        }
        else {
            setPref(Constants.CD_READER_KEY, "cdda2wav.exe");
            setPref(Constants.MP3_ENCODER_KEY, "lame.exe");
            setPref(Constants.OGG_ENCODER_KEY, "oggenc.exe");
            setPref(Constants.OGG_DECODER_KEY, "oggdec.exe");
            setPref(Constants.AAC_ENCODER_KEY, "faac.exe");
            setPref(Constants.AAC_DECODER_KEY, "faad.exe");
            setPref(Constants.FLAC_ENCODER_KEY, "flac.exe");

            if (DEVICE.length() == 0) {
                DEVICE = "1,0,0";
            }

            if (DIR.length() == 0) {
                DIR = "c:/Music";
            }
        }

        setPref(Constants.CD_SPEED_KEY, 0);
        setPref(Constants.PARANOIA_KEY, false);
        setPref(Constants.FILENAME_KEY, Constants.FILENAME_DEFAULT);
        setPref(Constants.DIRECTORY_KEY, Constants.DIRECTORY_DEFAULT);
        setPref(Constants.TITLE_KEY, Constants.TITLE_DEFAULT);
        setPref(Constants.FILENUMBER_KEY, Constants.FILENUMBER_DEFAULT);
        setPref(Constants.FILENUMBER_USE_KEY, Constants.FILENUMBER_USE_DEFAULT);
        setPref(Constants.FILENUMBER_SEPERATOR_KEY, Constants.FILENUMBER_SEPERATOR_DEFAULT);

        setPref(Constants.CD_DEVICE_KEY, DEVICE);
        setPref(Constants.BASE_DIRECTORY_KEY, DIR);
    }


    /**
     *
     */
    protected void tearDown() {
    }


    /**
     * @return Test
     */
    public static Test suite() {
        return new TestSuite(TestRippingAndTranscoding.class);
    }


    /**
     *
     */
    public void test01RippFromCD() {
        try {
            Command.DEBUG = false;
            Vector<BaseThread> threads = new Vector<BaseThread>();
            Vector<String> fnames = new Vector<String>();
            Album album = new Album("TestRippingAndTranscoding", "CD", "Rock", "2000", "This is a ripp from testcase test01RippFromCD");
            album.addTrack("MP3 Track Extreme", "", "");
            album.addTrack("MP3 Track High", "", "");
            album.addTrack("MP3 Track Normal", "", "");
            album.addTrack("MP3 Track Book", "", "");
            album.addTrack("OGG Track Extreme", "", "");
            album.addTrack("OGG Track High", "", "");
            album.addTrack("OGG Track Normal", "", "");
            album.addTrack("OGG Track Book", "", "");
            album.addTrack("AAC Track Extreme", "", "");
            album.addTrack("AAC Track High", "", "");
            album.addTrack("AAC Track Normal", "", "");
            album.addTrack("AAC Track Book", "", "");
            album.addTrack("FLAC", "", "");
            album.addTrack("WAV", "", "");

            int encoder = Constants.MP3_EXTREME_PARAM;
            //int encoder = Constants.AAC_EXTREME_PARAM;
            int count = 0;

            Progress.get().clear();
            for (Track track : album.aTracks) {
                track.aTrack = TRACKNUM;
                track.setEncoderIndex(encoder);
                fnames.add(track.createFileName(album, false));

                if (new File(fnames.get(count)).exists()) {
                    assertTrue(new File(fnames.get(count)).delete());
                }

                Command.createEncoderForCD(album, track, threads, fnames.lastElement(), false);
                count++;
                encoder++;
            }


            for (BaseThread thread : threads) {
                thread.run();
                Progress.get().nextWorkTask();
            }

            Log.get().addTime(1, "-------------------------------- CD Report");
            for (String fileName : fnames) {
                //assertTrue(new File(fileName).length() > 50000);
                if (new File(fileName).length() > 50000) {
                    Log.get().addTime(1, "_OK: " + fileName);
                }
                else {
                    Log.get().addTime(1, "_ER: " + fileName);
                }
            }
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test02TranscodingMP3() {
        try {
            Command.DEBUG = false;
            Vector<BaseThread> threads = new Vector<BaseThread>();
            Vector<String> fnames = new Vector<String>();
            Album album = new Album("TestRippingAndTranscoding", "MP3", "Rock", "2000", "This is a transcode from testcase test02TranscodingMP3");
            album.addTrack("MP3 Extreme To Ogg Extreme", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " MP3 Track Extreme.mp3"));
            album.addTrack("MP3 Extreme To AAC Extreme", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " MP3 Track Extreme.mp3"));
            album.addTrack("MP3 Extreme To FLAC", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " MP3 Track Extreme.mp3"));
            album.addTrack("MP3 Extreme To WAV", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " MP3 Track Extreme.mp3"));
            album.addTrack("MP3 Extreme To MP3 Book", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " MP3 Track Extreme.mp3"));

            album.aTracks.get(0).setEncoderIndex(Constants.OGG_EXTREME_PARAM);
            album.aTracks.get(1).setEncoderIndex(Constants.AAC_EXTREME_PARAM);
            album.aTracks.get(2).setEncoderIndex(Constants.FLAC_PARAM);
            album.aTracks.get(3).setEncoderIndex(Constants.WAV_PARAM);
            album.aTracks.get(4).setEncoderIndex(Constants.MP3_BOOK_PARAM);

            Progress.get().clear();
            for (Track track : album.aTracks) {
                track.aTrack = 1;
                fnames.add(track.createFileName(album, false));
                if (new File(fnames.lastElement()).exists()) {
                    assertTrue(new File(fnames.lastElement()).delete());
                }
                Command.createEncoderForFiles(album, track, threads, fnames.lastElement());
            }

            for (BaseThread thread : threads) {
                thread.run();
                Progress.get().nextWorkTask();
            }

            Log.get().addTime(1, "-------------------------------- MP3 Report");
            for (String fileName : fnames) {
                //assertTrue(new File(fileName).length() > 50000);
                if (new File(fileName).length() > 50000) {
                    Log.get().addTime(1, "_OK: " + fileName);
                }
                else {
                    Log.get().addTime(1, "_ER: " + fileName);
                }
            }
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test03TranscodingOGG() {
        try {
            Command.DEBUG = false;
            Vector<BaseThread> threads = new Vector<BaseThread>();
            Vector<String> fnames = new Vector<String>();
            Album album = new Album("TestRippingAndTranscoding", "OGG", "Rock", "2000", "This is a transcode from testcase test03TranscodingOGG");
            album.addTrack("OGG Extreme To MP3 Extreme", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " OGG Track Extreme.ogg"));
            album.addTrack("OGG Extreme To AAC Extreme", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " OGG Track Extreme.ogg"));
            album.addTrack("OGG Extreme To FLAC", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " OGG Track Extreme.ogg"));
            album.addTrack("OGG Extreme To WAV", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " OGG Track Extreme.ogg"));
            album.addTrack("OGG Extreme To OGG Book", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " OGG Track Extreme.ogg"));

            album.aTracks.get(0).setEncoderIndex(Constants.MP3_EXTREME_PARAM);
            album.aTracks.get(1).setEncoderIndex(Constants.AAC_EXTREME_PARAM);
            album.aTracks.get(2).setEncoderIndex(Constants.FLAC_PARAM);
            album.aTracks.get(3).setEncoderIndex(Constants.WAV_PARAM);
            album.aTracks.get(4).setEncoderIndex(Constants.OGG_BOOK_PARAM);

            Progress.get().clear();
            for (Track track : album.aTracks) {
                track.aTrack = 1;
                fnames.add(track.createFileName(album, false));
                if (new File(fnames.lastElement()).exists()) {
                    assertTrue(new File(fnames.lastElement()).delete());
                }
                Command.createEncoderForFiles(album, track, threads, fnames.lastElement());
            }

            for (BaseThread thread : threads) {
                thread.run();
                Progress.get().nextWorkTask();
            }

            Log.get().addTime(1, "-------------------------------- OGG Report");
            for (String fileName : fnames) {
                //assertTrue(new File(fileName).length() > 50000);
                if (new File(fileName).length() > 50000) {
                    Log.get().addTime(1, "_OK: " + fileName);
                }
                else {
                    Log.get().addTime(1, "_ER: " + fileName);
                }
            }
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test04TranscodingAAC() {
        try {
            Command.DEBUG = false;
            Vector<BaseThread> threads = new Vector<BaseThread>();
            Vector<String> fnames = new Vector<String>();
            Album album = new Album("TestRippingAndTranscoding", "AAC", "Rock", "2000", "This is a transcode from testcase test04TranscodingAAC");
            album.addTrack("AAC Extreme To MP3 Extreme", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " AAC Track Extreme.m4a"));
            album.addTrack("AAC Extreme To OGG Extreme", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " AAC Track Extreme.m4a"));
            album.addTrack("AAC Extreme To FLAC", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " AAC Track Extreme.m4a"));
            album.addTrack("AAC Extreme To WAV", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " AAC Track Extreme.m4a"));
            album.addTrack("AAC Extreme To AAC Book", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " AAC Track Extreme.m4a"));

            int count = 0;
            album.aTracks.get(count++).setEncoderIndex(Constants.MP3_EXTREME_PARAM);
            album.aTracks.get(count++).setEncoderIndex(Constants.OGG_EXTREME_PARAM);
            album.aTracks.get(count++).setEncoderIndex(Constants.FLAC_PARAM);
            album.aTracks.get(count++).setEncoderIndex(Constants.WAV_PARAM);
            album.aTracks.get(count++).setEncoderIndex(Constants.AAC_BOOK_PARAM);

            Progress.get().clear();
            for (Track track : album.aTracks) {
                track.aTrack = 1;
                fnames.add(track.createFileName(album, false));
                if (new File(fnames.lastElement()).exists()) {
                    assertTrue(new File(fnames.lastElement()).delete());
                }
                Command.createEncoderForFiles(album, track, threads, fnames.lastElement());
            }

            for (BaseThread thread : threads) {
                thread.run();
                Progress.get().nextWorkTask();
            }

            Log.get().addTime(1, "-------------------------------- AAC Report");
            for (String fileName : fnames) {
                //assertTrue(new File(fileName).length() > 50000);
                if (new File(fileName).length() > 50000) {
                    Log.get().addTime(1, "_OK: " + fileName);
                }
                else {
                    Log.get().addTime(1, "_ER: " + fileName);
                }
            }
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test05TranscodingFLAC() {
        try {
            Command.DEBUG = false;
            Vector<BaseThread> threads = new Vector<BaseThread>();
            Vector<String> fnames = new Vector<String>();
            Album album = new Album("TestRippingAndTranscoding", "FLAC", "Rock", "2000", "This is a transcode from testcase test05TranscodingFLAC");
            album.addTrack("FLAC To MP3 Extreme", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " FLAC.flac"));
            album.addTrack("FLAC To OGG Extreme", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " FLAC.flac"));
            album.addTrack("FLAC To AAC Extreme", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " FLAC.flac"));
            album.addTrack("FLAC To WAV", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " FLAC.flac"));
            album.addTrack("FLAC To FLAC", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " FLAC.flac"));

            album.aTracks.get(0).setEncoderIndex(Constants.MP3_EXTREME_PARAM);
            album.aTracks.get(1).setEncoderIndex(Constants.OGG_EXTREME_PARAM);
            album.aTracks.get(2).setEncoderIndex(Constants.AAC_EXTREME_PARAM);
            album.aTracks.get(3).setEncoderIndex(Constants.WAV_PARAM);
            album.aTracks.get(4).setEncoderIndex(Constants.FLAC_PARAM);

            Progress.get().clear();
            for (Track track : album.aTracks) {
                track.aTrack = 1;
                fnames.add(track.createFileName(album, false));
                if (new File(fnames.lastElement()).exists()) {
                    assertTrue(new File(fnames.lastElement()).delete());
                }
                Command.createEncoderForFiles(album, track, threads, fnames.lastElement());
            }

            for (BaseThread thread : threads) {
                thread.run();
                Progress.get().nextWorkTask();
            }

            Log.get().addTime(1, "-------------------------------- FLAC Report");
            for (String fileName : fnames) {
                //assertTrue(new File(fileName).length() > 50000);
                if (new File(fileName).length() > 50000) {
                    Log.get().addTime(1, "_OK: " + fileName);
                }
                else {
                    Log.get().addTime(1, "_ER: " + fileName);
                }
            }
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     *
     */
    public void test06TranscodingWAV() {
        try {
            Command.DEBUG = false;
            Vector<BaseThread> threads = new Vector<BaseThread>();
            Vector<String> fnames = new Vector<String>();
            Album album = new Album("TestRippingAndTranscoding", "WAV", "Rock", "2000", "This is a transcode from testcase test06TranscodingWAV");
            album.addTrack("WAV To MP3 Extreme", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " WAV.wav"));
            album.addTrack("WAV To OGG Extreme", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " WAV.wav"));
            album.addTrack("WAV To AAC Extreme", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " WAV.wav"));
            album.addTrack("WAV To FLAC", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " WAV.wav"));
            album.addTrack("WAV To WAV", new File(Pref.getPref(Constants.BASE_DIRECTORY_KEY, "") + File.separator + "TestRippingAndTranscoding" + File.separator + "CD" + File.separator + TRACKSTR + " WAV.wav"));

            album.aTracks.get(0).setEncoderIndex(Constants.MP3_EXTREME_PARAM);
            album.aTracks.get(1).setEncoderIndex(Constants.OGG_EXTREME_PARAM);
            album.aTracks.get(2).setEncoderIndex(Constants.AAC_EXTREME_PARAM);
            album.aTracks.get(3).setEncoderIndex(Constants.FLAC_PARAM);
            album.aTracks.get(4).setEncoderIndex(Constants.WAV_PARAM);

            Progress.get().clear();
            for (Track track : album.aTracks) {
                track.aTrack = 1;
                fnames.add(track.createFileName(album, false));
                if (new File(fnames.lastElement()).exists()) {
                    assertTrue(new File(fnames.lastElement()).delete());
                }
                Command.createEncoderForWavFiles(album, track, threads, fnames.lastElement());
            }

            for (BaseThread thread : threads) {
                thread.start();
                while (thread.isAlive()) {
                    Thread.sleep(100);
                    //Log.get().addTime(2, String.format("%d - %d%% done %s    %s", Progress.get().getMajorProgress(), Progress.get().getMinorProgress(), Progress.get().getMinorMessage(), Progress.get().getMajorMessage()));
                    //Log.get().addTime(1, String.format("%d - %d%% done %s    %s", Progress.get().getMajorProgress(), Progress.get().getMinorProgress(), Progress.get().getMinorMessage(), Progress.get().getMajorMessage()));
                }
                Progress.get().nextWorkTask();
            }

            Log.get().addTime(1, "-------------------------------- WAV Report");
            for (String fileName : fnames) {
                //assertTrue(new File(fileName).length() > 50000);
                if (new File(fileName).length() > 50000) {
                    Log.get().addTime(1, "_OK: " + fileName);
                }
                else {
                    Log.get().addTime(1, "_ER: " + fileName);
                }
            }
        }
        catch (Exception x) {
            x.printStackTrace();
            Assert.fail(x.getMessage());
        }
    }


    /**
     * @param args
     */
    public static void main(String[] args) {
        if (args.length == 2) {
            TestRippingAndTranscoding.DIR = args[0];
            TestRippingAndTranscoding.DEVICE = args[1];
            junit.textui.TestRunner.run(suite());
        }
        else {
            System.out.println("Arguments are base directory and device string");
        }
    }
}
